function deriv = dydt_transport(t,statevar)
%% Model Parameters

    global AR 
    global partitionheart partitionliver partitionspleen partitionlung partitionkidney partitionadi
    global kblooddis kbloodbind ktransblood km
    global kbindheart kbindliver  kbindspleen kbindlung kbindkidney kbindadi
    global kintheart kintliver kintspleen kintlung kintkidney kintadi
    global kelimt
    global Qheart Qliver  Qspleen Qlung  Qkidney Qadi Qc
    global kescendvec kunpackend kc
    
%% Model Variables

    Bcf = statevar(1);
    Bcb = statevar(2);
    Etheart = statevar(3);
    Etliver = statevar(4);
    Etspleen = statevar(5);
    Etlung = statevar(6);
    Etkidney = statevar(7);
    Etadi = statevar(8);
    Tbheart = statevar(9);
    Tbliver = statevar(10);
    Tbspleen = statevar(11);
    Tblung = statevar(12);
    Tbkidney = statevar(13);
    Tbadi = statevar(14);
    heart = statevar(15);
    liver = statevar(16);
    spleen = statevar(17);
    lung = statevar(18);
    kidney = statevar(19);
    adipocyte = statevar(20);
    Enc = statevar(21);
  
%% Model Equations
    if Bcf<0
        Bcf = 0;
    end
    
    dBcf = kblooddis*Bcb - kbloodbind*Bcf - (Etheart + Etliver + Etspleen + Etlung + Etkidney + Etadi);
    
    dBcb = kbloodbind*Bcf - kblooddis*Bcb;
   
    dEtheart = ktransblood*partitionheart*Qheart/Qc*Bcf - kbindheart*Etheart;
    
    dEtliver = ktransblood*partitionliver*Qliver/Qc*Bcf - kbindliver*Etliver;
    
    dEtspleen = ktransblood*partitionspleen*Qspleen/Qc*Bcf - kbindspleen*Etspleen;
     
    dEtlung= ktransblood*partitionlung*Qlung/Qc*Bcf - kbindlung*Etlung;
     
    dEtkidney = ktransblood*partitionkidney*Qkidney/Qc*Bcf - kbindkidney*Etkidney;
     
    dEtadi = ktransblood*partitionadi*Qadi/Qc*Bcf - kbindadi*Etadi - km*AR*Etadi;
     
    dTbheart = kbindheart*Etheart  - kintheart*Tbheart;
    
    dTbliver = kbindliver*Etliver - kintliver*Tbliver;
    
    dTbspleen = kbindspleen*Etspleen - kintspleen*Tbspleen;
    
    dTblung = kbindlung*Etlung - kintlung*Tblung;
    
    dTbkidney = kbindkidney*Etkidney - kintkidney*Tbkidney;
    
    dTbadi = kbindadi*Etadi - kintadi*Tbadi + km*AR*Etadi;
     
    dheart = kintheart*Tbheart - kelimt*heart;
    
    dliver = kintliver*Tbliver - kelimt*liver;
    
    dspleen = kintspleen*Tbspleen - kelimt*spleen;
    
    dlung = kintlung*Tblung - kelimt*lung;
    
    dkidney = kintkidney*Tbkidney - kelimt*kidney;
    
    dadi = kintadi*Tbadi - kelimt*adipocyte;
    
    dEnc = kc*(kintheart*Tbheart + kintliver*Tbliver + kintspleen*Tbspleen + kintlung*Tblung + kintkidney*Tbkidney + kintadi*Tbadi) - kescendvec*Enc;
    
     
    deriv = [dBcf;dBcb;dEtheart;dEtliver;dEtspleen;dEtlung;dEtkidney;dEtadi;dTbheart;dTbliver;dTbspleen;dTblung;dTbkidney;dTbadi;dheart;dliver;dspleen;dlung;dkidney;dadi;dEnc];
    
return