%%% This file contains codes simulating time-dependent tissue distribution
%%% of exosomes without RVG modification. In order to run the simulation,
%%% you need to put file 'dydt_transport.m'in the same diretory.The function 
%%% 'xticklabel_rotate' is written by Brain Katz and available at Matlab
%%% central.

clear

%% Step1: Define Constants
%%%%%%%%%% Model Parameters
 
    global AR 
    global partitionheart partitionliver partitionspleen partitionlung partitionkidney partitionadi
    global kblooddis kbloodbind ktransblood km
    global kbindheart kbindliver  kbindspleen kbindlung kbindkidney kbindadi
    global kintheart kintliver kintspleen kintlung kintkidney kintadi
    global kelimt
    global Qheart Qliver  Qspleen Qlung  Qkidney Qadi Qc
    global kescendvec kunpackend kc
    
    
    kblooddis = 1e-2/60; % min^-1
    kbloodbind = 1e-4/60; % min^-1
    ktransblood = 4e-1; % min^-1
  
    AR = 0; % #
    km = 1e-8; % #/min
    
    partitionheart = 1e-2;
    partitionliver = 1e-2;
    partitionspleen = 1e-3;
    partitionlung = 1e-3;
    partitionkidney = 1e-2;
    partitionadi = 1e-2;
    
    % min^-1
    kbindheart = 6e-1;
    kbindliver = 6e2;
    kbindspleen = 6;
    kbindlung = 6e-1;
    kbindkidney = 6;
    kbindadi = 1e2;
    
    % min^-1
    kintheart = 3e-2;
    kintliver = 3e-2;
    kintspleen = 1e2;
    kintlung = 1e2;
    kintkidney = 2e-2;
    kintadi = 1e2;
    
    % min^-1
    kelimt = 1e-2;
    
    Qc = 5.58; % L/min
    Qheart = Qc; 
    Qliver = 0.25*Qc;
    Qspleen = 0.10*Qc;
    Qlung = Qc;
    Qkidney = 0.3*Qc;
    Qadi = (1-0.25-0.10-0.3)*Qc;
    
    kescendvec = 1e-2/60; % min^-1
    kunpackend = 1e-3/60; % min^-1
    kc = 1e-11*6.02e23; % % convert pmol/ug to #/ug
    
%% Step2 Define Simulation Time
    tlast = 0:0.01:500; %% min

%% Step3 Initial Condition
    Bcf =  300; % ug
    Bcf_origin = Bcf;
    Bcb = 0;
    Etheart = 0;
    Etliver = 0;
    Etspleen = 0;
    Etlung = 0;
    Etkidney = 0;
    Etadi = 0;
    Tbheart = 0;
    Tbliver = 0;
    Tbspleen = 0;
    Tblung = 0;
    Tbkidney = 0;
    Tbadi = 0;
    heart = 0;
    liver = 0;
    spleen = 0;
    lung = 0;
    kidney = 0;
    adipocyte = 0;
    Enc = 0;
    
    statevar_i = [Bcf,Bcb,Etheart,Etliver,Etspleen,Etlung,Etkidney,Etadi,Tbheart,Tbliver,Tbspleen,Tblung,Tbkidney,Tbadi,heart,liver,spleen,lung,kidney,adipocyte,Enc];
    
%% Step4 Run Simulation
    
    [time,statevars] = ode15s(@dydt_transport,tlast,statevar_i);

    Bcf = statevars(:,1);
    Bcb = statevars(:,2);
    Etheart = statevars(:,3);
    Etliver = statevars(:,4);
    Etspleen = statevars(:,5);
    Etlung = statevars(:,6);
    Etkidney = statevars(:,7);
    Etadi = statevars(:,8);
    Tbheart = statevars(:,9);
    Tbliver = statevars(:,10);
    Tbspleen = statevars(:,11);
    Tblung = statevars(:,12);
    Tbkidney = statevars(:,13);
    Tbadi = statevars(:,14);
    heart = statevars(:,15);
    liver = statevars(:,16);
    spleen = statevars(:,17);
    lung = statevars(:,18);
    kidney = statevars(:,19);
    adipocyte = statevars(:,20);
    Enc = statevars(:,21);
   
%% Step5 Plot/Save Results

    colors = repmat('krgbmcy',1,300);
    tissue = char('blood','heart','liver','spleen','lung','kidney','adipocyte'); 
    figure
    hold on
    handle = gcf();
    plot(time,statevars(:,1)/Bcf_origin*100,colors(1),'LineWidth',2.25)
    figurelegend{1} = tissue(1,:);
    for i=2:7
    plot(time, statevars(:,i+13)/Bcf_origin*100,colors(i),'LineWidth',2.25)
    figurelegend{i} = tissue(i,:);
    end
    legend(figurelegend,'Location','Eastoutside')
    xlabel('Time/min','FontSize',14);
    ylabel('Percentage of total plasmids','FontSize',14);
    
    
    %%%% Barplot
    
    %%% group time = 1min
    i_1 = find(round(time)==1);
    i_1 = i_1(1);
    group_1 = [heart(i_1) liver(i_1) spleen(i_1) lung(i_1) kidney(i_1) adipocyte(i_1)];
    
    %%% group time = 5min
    i_5 = find(round(time)==5);
    i_5 = i_5(1);
    group_5 = [heart(i_5) liver(i_5) spleen(i_5) lung(i_5) kidney(i_5) adipocyte(i_5)];
    
    %%% group time = 10min
    i_10 = find(round(time)==10);
    i_10 = i_10(1);
    group_10 = [heart(i_10) liver(i_10) spleen(i_10) lung(i_10) kidney(i_10) adipocyte(i_10)];
    
    %%% group time = 30min
    i_30 = find(round(time)==30);
    i_30 = i_30(1);
    group_30 = [heart(i_30) liver(i_30) spleen(i_30) lung(i_30) kidney(i_30) adipocyte(i_30)];
    
    %%% group time = 60min
    i_60 = find(round(time)==60);
    i_60 = i_60(1);
    group_60 = [heart(i_60) liver(i_60) spleen(i_60) lung(i_60) kidney(i_60) adipocyte(i_60)];
    
    %%% group time = 240min
    i_240 = find(round(time)==240);
    i_240 = i_240(1);
    group_240 = [heart(i_240) liver(i_240) spleen(i_240) lung(i_240) kidney(i_240) adipocyte(i_240)];
    
    %%% group time = 480min
    i_480 = find(round(time)==480);
    i_480 = i_480(1);
    group_480 = [heart(i_480) liver(i_480) spleen(i_480) lung(i_480) kidney(i_480) adipocyte(i_480)];
    
    heart_bar = [group_1(1) group_5(1) group_10(1) group_30(1) group_60(1) group_240(1) group_480(1)];
    liver_bar = [group_1(2) group_5(2) group_10(2) group_30(2) group_60(2) group_240(2) group_480(2)];
    spleen_bar = [group_1(3) group_5(3) group_10(3) group_30(3) group_60(3) group_240(3) group_480(3)];
    lung_bar = [group_1(4) group_5(4) group_10(4) group_30(4) group_60(4) group_240(4) group_480(4)];
    kidney_bar = [group_1(5) group_5(5) group_10(5) group_30(5) group_60(5) group_240(5) group_480(5)];
    adipocyte_bar = [group_1(6) group_5(6) group_10(6) group_30(6) group_60(6) group_240(6) group_480(6)];
    
    y = [heart_bar;liver_bar;spleen_bar;lung_bar;kidney_bar;adipocyte_bar]/Bcf_origin*100;
  
    figure
    bar(y)
    set(gca,'FontSize',14, 'XTick',[1 2 3 4 5 6]); 
    xticklabel_rotate([1 2 3 4 5 6],45,{'Heart','Liver','Spleen','Lung','Kidney','adipocyte'});
    ylabel('Percentage of total plasmids','FontSize',14);
    legend('1min','5min','10min','30min','60min','240min','480min','Location','Eastoutside')